Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(312)

Unified Diff: tools/perf/page_sets/webrtc_cases.py

Issue 2909653003: Re-enable the multiple_peerconnections story and disable webrtc traces and metrics. (Closed)
Patch Set: Address comment. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/perf/benchmarks/webrtc.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/perf/page_sets/webrtc_cases.py
diff --git a/tools/perf/page_sets/webrtc_cases.py b/tools/perf/page_sets/webrtc_cases.py
index a6cacbaf071839d3661cf2a0ddea61aefe556f08..582dc53d95693f3c283192d4f0b72094ef9e1419 100644
--- a/tools/perf/page_sets/webrtc_cases.py
+++ b/tools/perf/page_sets/webrtc_cases.py
@@ -110,13 +110,13 @@ class MultiplePeerConnections(WebrtcPage):
def RunPageInteractions(self, action_runner):
with action_runner.CreateInteraction('Action_Create_PeerConnection',
repeatable=False):
# Set the number of peer connections to create to 15.
action_runner.ExecuteJavaScript(
- 'document.getElementById("num-peerconnections").value=15')
+ 'document.getElementById("num-peerconnections").value=10')
action_runner.ExecuteJavaScript(
'document.getElementById("cpuoveruse-detection").checked=false')
action_runner.ClickElement('button[id="start-test"]')
- action_runner.Wait(45)
+ action_runner.Wait(20)
class WebrtcPageSet(story.StorySet):
@@ -124,25 +124,35 @@ class WebrtcPageSet(story.StorySet):
super(WebrtcPageSet, self).__init__(
cloud_storage_bucket=story.PUBLIC_BUCKET)
- self.AddStory(GetUserMedia(self, tags=['getusermedia']))
self.AddStory(MultiplePeerConnections(self, tags=['stress']))
- self.AddStory(VideoCall(self, tags=['peerconnection', 'smoothness']))
self.AddStory(DataChannel(self, tags=['datachannel']))
+ self.AddStory(GetUserMedia(self, tags=['getusermedia']))
+ self.AddStory(VideoCall(self, tags=['peerconnection', 'smoothness']))
self.AddStory(CanvasCapturePeerConnection(self, tags=['smoothness']))
- # TODO(qyearsley, mcasas): Add webrtc.audio when http://crbug.com/468732
- # is fixed, or revert https://codereview.chromium.org/1544573002/ when
- # http://crbug.com/568333 is fixed.
- # self.AddStory(AudioCall(self, 'OPUS'))
- # self.AddStory(AudioCall(self, 'G772'))
- # self.AddStory(AudioCall(self, 'PCMU'))
- # self.AddStory(AudioCall(self, 'ISAC/1600'))
+ self.AddStory(AudioCall(self, 'OPUS', tags=['audio']))
+ self.AddStory(AudioCall(self, 'G772', tags=['audio']))
+ self.AddStory(AudioCall(self, 'PCMU', tags=['audio']))
+ self.AddStory(AudioCall(self, 'ISAC/1600', tags=['audio']))
class WebrtcExpectations(story.expectations.StoryExpectations):
def SetExpectations(self):
- self.DisableStory('multiple_peerconnections',
+ # TODO(qyearsley, mcasas): Add webrtc.audio when http://crbug.com/468732
+ # is fixed, or revert https://codereview.chromium.org/1544573002/ when
+ # http://crbug.com/568333 is fixed.
+ self.DisableStory('audio_call_opus_10s',
+ [story.expectations.ALL],
+ 'crbug.com/468732')
+ self.DisableStory('audio_call_g772_10s',
[story.expectations.ALL],
- 'crbug.com/725502')
+ 'crbug.com/468732')
+ self.DisableStory('audio_call_pcmu_10s',
+ [story.expectations.ALL],
+ 'crbug.com/468732')
+ self.DisableStory('audio_call_isac/1600_10s',
+ [story.expectations.ALL],
+ 'crbug.com/468732')
+
self.DisableStory('30s_datachannel_transfer',
[story.expectations.ALL_DESKTOP],
'crbug.com/726811')
@@ -110,13 +110,13 @@ class MultiplePeerConnections(WebrtcPage):
with action_runner.CreateInteraction('Action_Create_PeerConnection',
repeatable=False):
- # Set the number of peer connections to create to 15.
+ # Set the number of peer connections to create to 10.
action_runner.ExecuteJavaScript(
« no previous file with comments | « tools/perf/benchmarks/webrtc.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698